@@ -143,9 +143,16 @@ class Command(BaseCommand):
         password = options.password or os.getenv("PDM_PUBLISH_PASSWORD")
         ca_certs = options.ca_certs or os.getenv("PDM_PUBLISH_CA_CERTS")
 
-        config = project.global_config.get_repository_config(repository, "repository")
+        config = project.project_config.get_repository_config(repository, "repository")
         if config is None:
-            raise PdmUsageError(f"Missing repository config of {repository}")
+            config = project.global_config.get_repository_config(repository, "repository")
+            if config is None:
+                raise PdmUsageError(f"Missing repository config of {repository}")
+        else:
+            global_config = project.global_config.get_repository_config(repository, "repository")
+            if global_config is not None:
+                config.passive_update(global_config)
+
         assert config.url is not None
         if username is not None:
             config.username = username
@@ -155,6 +162,7 @@ class Command(BaseCommand):
             config.ca_certs = ca_certs
         if options.verify_ssl is False:
             config.verify_ssl = options.verify_ssl
+        config.populate_auth()
         return Repository(project, config)
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
