@@ -164,10 +164,7 @@ class TaskRunner:
         tool_config = metadata.pop("tool", {})
         script_project = self.project.core.create_project()
         script_project.pyproject.set_data({"project": metadata, "tool": tool_config})
-        md5_kwargs = {}
-        # for python >= 3.9, indicate that md5 is not used in a security context
-        if sys.version_info >= (3, 9):
-            md5_kwargs = {"usedforsecurity": False}
+        md5_kwargs = {"usedforsecurity": False}
         venv_name = hashlib.md5(os.path.realpath(script_file).encode("utf-8"), **md5_kwargs).hexdigest()
         venv_backend = BACKENDS[script_project.config["venv.backend"]](script_project, None)
         venv = venv_backend.get_location(None, venv_name)
@@ -290,13 +287,15 @@ class TaskRunner:
                 signum = signal.SIGTERM
             process.send_signal(signum)
 
+        process_env = os.environ.copy()
+        process_env.update({"PDM_RUN_CWD": str(Path.cwd())})
         handle_term = signal.signal(signal.SIGTERM, forward_signal)
         handle_int = signal.signal(signal.SIGINT, forward_signal)
-        process = subprocess.Popen(process_cmd, cwd=cwd, shell=shell, bufsize=0)
-        process.wait()
+        process = subprocess.Popen(process_cmd, cwd=cwd, shell=shell, bufsize=0, close_fds=False, env=process_env)
+        retcode = process.wait()
         signal.signal(signal.SIGTERM, handle_term)
         signal.signal(signal.SIGINT, handle_int)
-        return process.returncode
+        return retcode
 
     def run_task(
         self, task: Task, args: Sequence[str] = (), opts: TaskOptions | None = None, seen: set[str] | None = None
@@ -342,11 +341,8 @@ class TaskRunner:
         elif kind == "composite":
             assert isinstance(value, list)
 
-        self.project.core.ui.echo(
-            f"Running {task}: [success]{args}[/]",
-            err=True,
-            verbosity=termui.Verbosity.DETAIL,
-        )
+        self.display_task(task, args)
+
         if kind == "composite":
             args = list(args)
             should_interpolate = any(RE_ARGS_PLACEHOLDER.search(script) for script in value)
@@ -367,6 +363,19 @@ class TaskRunner:
             return composite_code
         return self._run_process(args, chdir=True, shell=shell, **merge_options(self.global_options, options, opts))  # type: ignore[misc]
 
+    def display_task(self, task: Task, args: Sequence[str]) -> None:
+        """Display a task given current verbosity and settings"""
+        is_verbose = self.project.core.ui.verbosity >= termui.Verbosity.DETAIL
+        if not (is_verbose or self.project.config.get("scripts.show_header")):
+            return
+        args = task.args if task.kind == "composite" else args
+        content = args if is_verbose else task.short_description
+        self.project.core.ui.echo(
+            f"Running {task}: [success]{content}[/]",
+            err=True,
+            verbosity=termui.Verbosity.NORMAL,
+        )
+
     def run(
         self,
         command: str,
