@@ -65,6 +65,7 @@ def _resolve_dependency_group(
     past_groups: tuple[str, ...] = (),
     optional_dependencies: dict[str, list[str]] | None = None,
     allow_optional: bool = False,
+    recursive_resolve: bool = True,
 ) -> tuple[list[str], dict[str, set[str]]]:
     optional_dependencies = optional_dependencies or {}
     if group in past_groups:
@@ -94,26 +95,28 @@ def _resolve_dependency_group(
                 pass
             else:
                 if normalize_name(req) == project_name:
-                    for extra in extras or ():
-                        resolved, referred = _resolve_dependency_group(
-                            project_name,
-                            child_dependencies,
-                            extra,
-                            (*past_groups, group),
-                            optional_dependencies,
-                            # `self[extra]` is allowed to refer to optional dependency groups
-                            allow_optional=True,
-                        )
-                        realized_group.extend(resolved)
-                        for k, v in referred.items():
-                            referred_groups.setdefault(k, {group}).update(v)
+                    if recursive_resolve:
+                        for extra in extras or ():
+                            resolved, referred = _resolve_dependency_group(
+                                project_name,
+                                child_dependencies,
+                                extra,
+                                (*past_groups, group),
+                                optional_dependencies,
+                                # `self[extra]` is allowed to refer to optional dependency groups
+                                allow_optional=True,
+                            )
+                            realized_group.extend(resolved)
+                            for k, v in referred.items():
+                                referred_groups.setdefault(k, {group}).update(v)
                     continue
             realized_group.append(item)
             referred_groups.setdefault(item, {group})
         elif isinstance(item, dict):
             if tuple(item.keys()) != ("include-group",):
                 raise ProjectError(f"Invalid dependency group item: {item}")
-
+            if not recursive_resolve:
+                continue
             include_group = normalize_name(next(iter(item.values())))
             resolved, referred = _resolve_dependency_group(
                 project_name,
@@ -304,6 +307,8 @@ class Project:
             python = PythonInfo.from_path(saved_path)
             if match_version(python):
                 return python
+            elif not python.valid:
+                note("The saved Python interpreter does not exist or broken. Trying to find another one.")
             else:
                 note(
                     "The saved Python interpreter doesn't match the project's requirement. "
@@ -398,10 +403,10 @@ class Project:
     def python_requires(self) -> PySpecSet:
         return PySpecSet(self.pyproject.metadata.get("requires-python", ""))
 
-    def get_dependencies(self, group: str | None = None) -> Sequence[Requirement]:
+    def get_dependencies(self, group: str | None = None, resolve_include: bool = True) -> Sequence[Requirement]:
         metadata = self.pyproject.metadata
-        group = group or "default"
-        optional_dependencies = metadata.get("optional-dependencies", {})
+        group = normalize_name(group or "default")
+        optional_dependencies = {normalize_name(k): v for k, v in metadata.get("optional-dependencies", {}).items()}
         dev_dependencies = self.pyproject.dev_dependencies
         in_metadata = group == "default" or group in optional_dependencies
         referred_groups: dict[str, set[str]] = {}
@@ -415,10 +420,12 @@ class Project:
                     "and \\[dependency-groups], the former is taken."
                 )
             if group in optional_dependencies:
-                deps, referred_groups = _resolve_dependency_group(project_name, optional_dependencies, group, ())
+                deps, referred_groups = _resolve_dependency_group(
+                    project_name, optional_dependencies, group, (), recursive_resolve=resolve_include
+                )
             elif group in dev_dependencies:
                 deps, referred_groups = _resolve_dependency_group(
-                    project_name, dev_dependencies, group, (), optional_dependencies
+                    project_name, dev_dependencies, group, (), optional_dependencies, recursive_resolve=resolve_include
                 )
             else:
                 raise PdmUsageError(f"Non-exist group {group}")
@@ -442,17 +449,18 @@ class Project:
         groups = {"default"}
         if self.pyproject.metadata.get("optional-dependencies"):
             groups.update(self.pyproject.metadata["optional-dependencies"].keys())
-        groups.update(self.pyproject.dev_dependencies.keys())
+        groups.update(self.pyproject._data.get("dependency-groups", {}).keys())
+        groups.update(self.pyproject.settings.get("dev-dependencies", {}).keys())
         return groups
 
     @property
     def all_dependencies(self) -> dict[str, Sequence[Requirement]]:
-        return {group: self.get_dependencies(group) for group in self.iter_groups()}
+        return {group: self.get_dependencies(group, resolve_include=False) for group in self.iter_groups()}
 
     @property
     def default_source(self) -> RepositoryConfig:
         """Get the default source from the pypi setting"""
-        return RepositoryConfig(
+        config = RepositoryConfig(
             config_prefix="pypi",
             name="pypi",
             url=self.config["pypi.url"],
@@ -463,6 +471,8 @@ class Project:
             client_cert=self.config.get("pypi.client_cert"),
             client_key=self.config.get("pypi.client_key"),
         )
+        config.populate_auth()
+        return config
 
     @property
     def sources(self) -> list[RepositoryConfig]:
@@ -495,6 +505,7 @@ class Project:
                 continue
             if expand_env:
                 source.url = DEFAULT_BACKEND(self.root).expand_line(expand_env_vars_in_auth(source.url))
+            source.populate_auth()
             sources.append(source)
         return sources
 
@@ -637,13 +648,13 @@ class Project:
         def update_dev_dependencies(deps: list[str]) -> None:
             from tomlkit.container import OutOfOrderTableProxy
 
-            dependency_groups: list[str | dict[str, str]] = []
-            dev_dependencies: list[str] = []
+            dependency_groups: list[str | dict[str, str]] = tomlkit.array().multiline(True)
+            dev_dependencies: list[str] = tomlkit.array().multiline(True)
             for dep in deps:
-                if dep.startswith("-e"):
+                if isinstance(dep, str) and dep.startswith("-e"):
                     dev_dependencies.append(dep)
-                    continue
-                dependency_groups.append(dep)
+                else:
+                    dependency_groups.append(dep)
             if dependency_groups:
                 self.pyproject.dependency_groups[group] = dependency_groups
             else:
@@ -662,6 +673,8 @@ class Project:
         metadata, settings = self.pyproject.metadata, self.pyproject.settings
         if group == "default":
             return metadata.get("dependencies", tomlkit.array()), lambda x: metadata.__setitem__("dependencies", x)
+        dev_dependencies = self.pyproject._data.get("dependency-groups", {})
+        dev_dependencies.update(self.pyproject.settings.get("dev-dependencies", {}))
         deps_setter = [
             (
                 metadata.get("optional-dependencies", {}),
@@ -669,13 +682,17 @@ class Project:
                 if x
                 else metadata.setdefault("optional-dependencies", {}).pop(group, None),
             ),
-            (self.pyproject.dev_dependencies, update_dev_dependencies),
+            (dev_dependencies, update_dev_dependencies),
         ]
+        normalized_group = normalize_name(group)
         for deps, setter in deps_setter:
+            normalized_groups = {normalize_name(g) for g in deps}
             if group in deps:
                 return make_array(deps[group], True), setter
+            if normalized_group in normalized_groups:
+                raise PdmUsageError(f"Group {group} already exists in another non-normalized form")
         # If not found, return an empty list and a setter to add the group
-        return tomlkit.array(), deps_setter[int(dev)][1]
+        return tomlkit.array().multiline(True), deps_setter[int(dev)][1]
 
     def add_dependencies(
         self,
@@ -695,13 +712,17 @@ class Project:
         updated_indices: set[int] = set()
 
         with cd(self.root):
-            parsed_deps = [parse_line(dep) for dep in deps]
+            parsed_deps = [(parse_line(dep) if isinstance(dep, str) else None) for dep in deps]
 
             for req in requirements:
                 if isinstance(req, str):
                     req = parse_line(req)
                 matched_index = next(
-                    (i for i, r in enumerate(deps) if req.matches(r) and i not in updated_indices),
+                    (
+                        i
+                        for i, r in enumerate(deps)
+                        if isinstance(r, str) and req.matches(r) and i not in updated_indices
+                    ),
                     None,
                 )
                 dep = req.as_line()
@@ -717,8 +738,9 @@ class Project:
         if write:
             self.pyproject.write(show_message)
         for r in parsed_deps:
-            r.groups = [to_group]
-        return parsed_deps
+            if r is not None:
+                r.groups = [to_group]
+        return [r for r in parsed_deps if r is not None]
 
     def init_global_project(self) -> None:
         if not self.is_global or not self.pyproject.empty():
@@ -934,22 +956,22 @@ class Project:
     def lock_targets(self) -> list[EnvSpec]:
         return [self.environment.allow_all_spec]
 
-    def get_resolver(self) -> type[Resolver]:
+    def get_resolver(self, allow_uv: bool = True) -> type[Resolver]:
         """Get the resolver class to use for the project."""
         from pdm.resolver.resolvelib import RLResolver
         from pdm.resolver.uv import UvResolver
 
-        if self.config.get("use_uv"):
+        if allow_uv and self.config.get("use_uv"):
             return UvResolver
         else:
             return RLResolver
 
-    def get_synchronizer(self, quiet: bool = False) -> type[BaseSynchronizer]:
+    def get_synchronizer(self, quiet: bool = False, allow_uv: bool = True) -> type[BaseSynchronizer]:
         """Get the synchronizer class to use for the project."""
         from pdm.installers import BaseSynchronizer, Synchronizer, UvSynchronizer
         from pdm.installers.uv import QuietUvSynchronizer
 
-        if self.config.get("use_uv"):
+        if allow_uv and self.config.get("use_uv"):
             return QuietUvSynchronizer if quiet else UvSynchronizer
         if quiet:
             return BaseSynchronizer
