@@ -4,7 +4,7 @@ import os
 from functools import cached_property
 from typing import TYPE_CHECKING, Callable
 
-from packaging.specifiers import InvalidSpecifier, SpecifierSet
+from packaging.specifiers import InvalidSpecifier
 from packaging.version import InvalidVersion
 from resolvelib import AbstractProvider, RequirementsConflicted
 from resolvelib.resolvers import Criterion
@@ -16,7 +16,13 @@ from pdm.models.requirements import FileRequirement, Requirement, parse_requirem
 from pdm.models.specifiers import PySpecSet
 from pdm.resolver.python import PythonCandidate, PythonRequirement, find_python_matches, is_python_satisfied_by
 from pdm.termui import logger
-from pdm.utils import deprecation_warning, is_url, normalize_name, parse_version, url_without_fragments
+from pdm.utils import (
+    deprecation_warning,
+    get_requirement_from_override,
+    normalize_name,
+    parse_version,
+    url_without_fragments,
+)
 
 if TYPE_CHECKING:
     from typing import Any, Iterable, Iterator, Mapping, Sequence, TypeVar
@@ -30,23 +36,23 @@ if TYPE_CHECKING:
     ProviderT = TypeVar("ProviderT", bound="type[BaseProvider]")
 
 
-_PROVIDER_REGISTORY: dict[str, type[BaseProvider]] = {}
+_PROVIDER_REGISTRY: dict[str, type[BaseProvider]] = {}
 
 
 def get_provider(strategy: str) -> type[BaseProvider]:
-    return _PROVIDER_REGISTORY[strategy]
+    return _PROVIDER_REGISTRY[strategy]
 
 
 def register_provider(strategy: str) -> Callable[[ProviderT], ProviderT]:
     def wrapper(cls: ProviderT) -> ProviderT:
-        _PROVIDER_REGISTORY[strategy] = cls
+        _PROVIDER_REGISTRY[strategy] = cls
         return cls
 
     return wrapper
 
 
 @register_provider("all")
-class BaseProvider(AbstractProvider):
+class BaseProvider(AbstractProvider[Requirement, Candidate, str]):
     def __init__(
         self,
         repository: BaseRepository,
@@ -71,12 +77,11 @@ class BaseProvider(AbstractProvider):
         self.excludes = {normalize_name(k) for k in project.pyproject.resolution.get("excludes", [])}
         self.direct_minimal_versions = direct_minimal_versions
         self.locked_candidates = locked_candidates
-        self._known_depth: dict[str, int] = {}
 
     def requirement_preference(self, requirement: Requirement) -> Comparable:
         """Return the preference of a requirement to find candidates.
 
-        - Editable requirements are preferered.
+        - Editable requirements are preferred.
         - File links are preferred.
         - The one with narrower specifierset is preferred.
         """
@@ -102,14 +107,6 @@ class BaseProvider(AbstractProvider):
         backtrack_identifiers = {req.identify() for req, _ in backtrack_causes} | {
             parent.identify() for _, parent in backtrack_causes if parent is not None
         }
-        if is_top:
-            dep_depth = 1
-        else:
-            parent_depths = (
-                self._known_depth[parent.identify()] if parent is not None else 0
-                for _, parent in information[identifier]
-            )
-            dep_depth = min(parent_depths, default=0) + 1
         # Use the REAL identifier as it may be updated after candidate preparation.
         deps: list[Requirement] = []
         for candidate in candidates[identifier]:
@@ -118,7 +115,6 @@ class BaseProvider(AbstractProvider):
             except RequirementsConflicted:
                 continue
             break
-        self._known_depth[self.identify(candidate)] = dep_depth
         is_backtrack_cause = any(dep.identify() in backtrack_identifiers for dep in deps)
         is_file_or_url = any(not requirement.is_named for requirement, _ in information[identifier])
         operators = [spec.operator for req, _ in information[identifier] for spec in req.specifier]
@@ -131,7 +127,6 @@ class BaseProvider(AbstractProvider):
             not is_file_or_url,
             not is_pinned,
             not is_backtrack_cause,
-            dep_depth,
             -constraints,
             identifier,
         )
@@ -147,15 +142,7 @@ class BaseProvider(AbstractProvider):
         }
         requirements: dict[str, Requirement] = {}
         for name, value in project_overrides.items():
-            if is_url(value):
-                req = f"{name} @ {value}"
-            else:
-                try:
-                    SpecifierSet(value)
-                except InvalidSpecifier:
-                    req = f"{name}=={value}"
-                else:
-                    req = f"{name}{value}"
+            req = get_requirement_from_override(name, value)
             r = parse_requirement(req)
             requirements[r.identify()] = r
 
@@ -181,7 +168,7 @@ class BaseProvider(AbstractProvider):
             can = Candidate(requirement)
             if not can.name:
                 can.prepare(self.repository.environment).metadata
-            return [can]
+            yield can
         else:
             prerelease = requirement.prerelease
             if prerelease is None and requirement.is_pinned and requirement.specifier.prereleases:
@@ -199,12 +186,38 @@ class BaseProvider(AbstractProvider):
                             if parsed_version.is_prerelease:
                                 prerelease = True
                                 break
-            return self.repository.find_candidates(
+            found = self.repository.find_candidates(
                 requirement,
                 self.allow_prereleases if prerelease is None else prerelease,
                 minimal_version=self.direct_minimal_versions and self._is_direct_requirement(requirement),
             )
 
+            current_version: str | None = None
+            collected_wheels: list[Candidate] = []
+            collected_others: list[Candidate] = []
+            for candidate in found:
+                assert candidate.version is not None
+                if current_version is None:
+                    current_version = candidate.version
+                if candidate.version != current_version:
+                    # If there are wheels for the given version, we should only return wheels
+                    # to avoid build steps.
+                    if collected_wheels:
+                        yield from collected_wheels
+                    else:
+                        yield from collected_others
+                    current_version = candidate.version
+                    collected_wheels.clear()
+                    collected_others.clear()
+                if candidate.link and candidate.link.is_wheel:
+                    collected_wheels.append(candidate)
+                else:
+                    collected_others.append(candidate)
+            if collected_wheels:
+                yield from collected_wheels
+            else:
+                yield from collected_others
+
     def find_matches(
         self,
         identifier: str,
